@@ -136,6 +136,8 @@ def process_event(
             # CAPTURES:
             #    lpipe.exceptions.InvalidConfigurationError
             # raise (later)
+            if exception_handler:
+                exception_handler(e)
             _exceptions.append({"exception": e, "record": encoded_record})
         _output.append(ret)
 
@@ -147,8 +149,8 @@ def process_event(
         # Handle cleanup for successful records, if necessary, before creating an error state.
         advanced_cleanup(queue_type, successful_records, logger)
 
-        logger.info(
-            f"Encountered exceptions while handling one or more records. RESPONSE: {response}"
+        logger.error(
+            f"Encountered exceptions while handling one or more records: {response}"
         )
         raise lpipe.exceptions.FailCatastrophically(_exceptions)
 
